ImageMetadata

Struct ImageMetadata 

pub struct ImageMetadata {
    pub format: ImageFormat,
    pub kind: ImageKind,
    pub mime_type: Option<&'static str>,
    pub extension: Option<&'static str>,
    pub size: Option<ImageSize>,
}
Small image metadata bundle for callers that already know or discovered a format.

Fields

format: ImageFormatkind: ImageKindmime_type: Option<&'static str>extension: Option<&'static str>size: Option<ImageSize>

Implementations

Source

impl ImageMetadata

pub fn new(format: ImageFormat) -> ImageMetadata

Builds metadata from a detected format without embedded size information.

pub fn with_size(format: ImageFormat, size: Option<ImageSize>) -> ImageMetadata

Builds metadata from a detected format and optional size information.